# 考虑是否要安装卡夫卡


scp dist/* zhaoxuefeng@192.168.1.165:/Users/zhaoxuefeng/pypi-simple-server/packages

scp dist/*  root@39.96.146.47:/root/workspace

Aihuashen2025


# doubao-1-5-pro-32k-250115
# doubao-seed-1-6-lite-251015

# 每一个都要欧description, response_description



# 如何维护服务

1 修改代码(开发环境)
    修改代码
    启动测试环境服务
    进行单元测试, 等等
    修改代码等等
    final: 打包